==> vice_3.4.0.dfsg.orig.tar.xz: vice-3.4.0.dfsg/src/vic20/cart/megacart.h <==
/*
 * megacart.h -- VIC20 Mega-Cart emulation.
 *
 * Written by
 *  Daniel Kahlin <daniel@kahlin.net>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef VICE_MEGACART_H
#define VICE_MEGACART_H

#include <stdio.h>

#include "types.h"

extern uint8_t megacart_ram123_read(uint16_t addr);
extern void megacart_ram123_store(uint16_t addr, uint8_t value);
extern uint8_t megacart_blk123_read(uint16_t addr);
extern void megacart_blk123_store(uint16_t addr, uint8_t value);
extern uint8_t megacart_blk5_read(uint16_t addr);
extern void megacart_blk5_store(uint16_t addr, uint8_t value);

extern void megacart_init(void);
extern void megacart_reset(void);

extern void megacart_config_setup(uint8_t *rawcart);
extern int megacart_bin_attach(const char *filename);
/* extern int megacart_bin_attach(const char *filename, uint8_t *rawcart); */
/* extern int megacart_crt_attach(FILE *fd, uint8_t *rawcart); */
extern void megacart_detach(void);

extern int megacart_resources_init(void);
extern void megacart_resources_shutdown(void);
extern int megacart_cmdline_options_init(void);

struct snapshot_s;

extern int megacart_snapshot_write_module(struct snapshot_s *s);
extern int megacart_snapshot_read_module(struct snapshot_s *s);

#endif

==> vice_3.7.1+dfsg1.orig.tar.xz: vice-3.7.1+dfsg/src/vic20/cart/megacart.h <==
/*
 * megacart.h -- VIC20 Mega-Cart emulation.
 *
 * Written by
 *  Daniel Kahlin <daniel@kahlin.net>
 *
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 *
 */

#ifndef VICE_MEGACART_H
#define VICE_MEGACART_H

#include <stdio.h>

#include "types.h"

extern uint8_t megacart_ram123_read(uint16_t addr);
extern void megacart_ram123_store(uint16_t addr, uint8_t value);
extern uint8_t megacart_blk123_read(uint16_t addr);
extern void megacart_blk123_store(uint16_t addr, uint8_t value);
extern uint8_t megacart_blk5_read(uint16_t addr);
extern void megacart_blk5_store(uint16_t addr, uint8_t value);

extern void megacart_init(void);
extern void megacart_reset(void);
extern void megacart_powerup(void);

extern void megacart_config_setup(uint8_t *rawcart);
extern int megacart_bin_attach(const char *filename);
/* extern int megacart_bin_attach(const char *filename, uint8_t *rawcart); */
extern int megacart_crt_attach(FILE *fd, uint8_t *rawcart);
extern void megacart_detach(void);

extern int megacart_resources_init(void);
extern void megacart_resources_shutdown(void);
extern int megacart_cmdline_options_init(void);

struct snapshot_s;

extern int megacart_snapshot_write_module(struct snapshot_s *s);
extern int megacart_snapshot_read_module(struct snapshot_s *s);

#endif
